pub enum SymmetricKeyEnvelopeError {
WrongKey,
Parsing(String),
KeyMissing,
KeyStore,
WrongKeyType,
InvalidNamespace,
}Expand description
Errors that can occur when sealing or unsealing a symmetric key with envelope operations.
Variants
WrongKey
The wrapping key provided is incorrect or the envelope was tampered with
Parsing(String)
The envelope could not be parsed correctly
KeyMissing
There is no key for the provided key id in the key store
KeyStore
The key store could not be written to, for example due to being read-only
WrongKeyType
The wrong unseal method was used for the key type
InvalidNamespace
The symmetric key envelope namespace is invalid.